@@ -19,14 +19,15 @@
 import unittest
 
 import biggus
+from biggus._init import _Aggregation
 from biggus.tests import mock
 
 
 class Test(unittest.TestCase):
     def test(self):
         # If we switch evaluation engine, does it get used?
-        array = biggus._Aggregation(biggus.ConstantArray(3, 2), None, None,
-                                    None, None, {})
+        array = _Aggregation(biggus.ConstantArray(3, 2), None, None, None,
+                             None, {})
         return_value = (mock.sentinel.result,)
         engine = mock.Mock(**{'ndarrays.return_value': return_value})
         with mock.patch('biggus.engine', engine):
