@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2015, Met Office
+# (C) British Crown Copyright 2015 - 2016, Met Office
 #
 # This file is part of Biggus.
 #
@@ -21,7 +21,7 @@ import numpy.ma as ma
 import unittest
 
 import biggus
-import biggus.tests.unit._aggregation_test_framework as test_framework
+import biggus.tests.unit.init._aggregation_test_framework as test_framework
 
 
 class TestSum(unittest.TestCase):
